Take somewhat more spacing for move sorting
authorH.G. Muller <h.g.muller@hccnet.nl>
Fri, 18 Jan 2013 16:07:14 +0000 (17:07 +0100)
committerH.G. Muller <h.g.muller@hccnet.nl>
Fri, 18 Jan 2013 16:07:14 +0000 (17:07 +0100)
The gaps in the move stack are now 50 in stead of 20.

hachu.c

diff --git a/hachu.c b/hachu.c
index ca7f32d..d28e99e 100644 (file)
--- a/hachu.c
+++ b/hachu.c
@@ -1523,7 +1523,7 @@ if(PATH) /*pboard(board),pmap(attacks, BLACK),*/printf("search(%d) {%d,%d} eval=
   nodes++;\r
   pv[pvPtr++] = 0; // start empty PV, directly behind PV of parent\r
 \r
-  firstMove = curMove = sorted = msp += 20; // leave 20 empty slots in front of move list\r
+  firstMove = curMove = sorted = msp += 50; // leave 50 empty slots in front of move list\r
   tb.fireMask = phase = 0; iterDep=1; replyDep = (depth < 1 ? depth : 1) - 1;\r
   do {\r
 if(flag && depth>= 0) printf("iter %d:%d\n", depth,iterDep),fflush(stdout);\r